@@ -16,8 +16,20 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
+
+from google.cloud.firestore_admin_v1 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -70,7 +82,7 @@ class FirestoreAdminClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[FirestoreAdminTransport]:
         """Returns an appropriate transport class.
 
@@ -441,8 +453,8 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, FirestoreAdminTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, FirestoreAdminTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the firestore admin client.
@@ -456,7 +468,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
             transport (Union[str, FirestoreAdminTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -486,6 +498,7 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -538,12 +551,12 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def create_index(
         self,
-        request: Union[firestore_admin.CreateIndexRequest, dict] = None,
+        request: Optional[Union[firestore_admin.CreateIndexRequest, dict]] = None,
         *,
-        parent: str = None,
-        index: gfa_index.Index = None,
+        parent: Optional[str] = None,
+        index: Optional[gfa_index.Index] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Creates a composite index. This returns a
@@ -668,11 +681,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def list_indexes(
         self,
-        request: Union[firestore_admin.ListIndexesRequest, dict] = None,
+        request: Optional[Union[firestore_admin.ListIndexesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListIndexesPager:
         r"""Lists composite indexes.
@@ -783,11 +796,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def get_index(
         self,
-        request: Union[firestore_admin.GetIndexRequest, dict] = None,
+        request: Optional[Union[firestore_admin.GetIndexRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> index.Index:
         r"""Gets a composite index.
@@ -886,11 +899,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def delete_index(
         self,
-        request: Union[firestore_admin.DeleteIndexRequest, dict] = None,
+        request: Optional[Union[firestore_admin.DeleteIndexRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a composite index.
@@ -976,11 +989,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def get_field(
         self,
-        request: Union[firestore_admin.GetFieldRequest, dict] = None,
+        request: Optional[Union[firestore_admin.GetFieldRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> field.Field:
         r"""Gets the metadata and configuration for a Field.
@@ -1081,11 +1094,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def update_field(
         self,
-        request: Union[firestore_admin.UpdateFieldRequest, dict] = None,
+        request: Optional[Union[firestore_admin.UpdateFieldRequest, dict]] = None,
         *,
-        field: gfa_field.Field = None,
+        field: Optional[gfa_field.Field] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Updates a field configuration. Currently, field updates apply
@@ -1220,11 +1233,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def list_fields(
         self,
-        request: Union[firestore_admin.ListFieldsRequest, dict] = None,
+        request: Optional[Union[firestore_admin.ListFieldsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFieldsPager:
         r"""Lists the field configuration and metadata for this database.
@@ -1343,11 +1356,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def export_documents(
         self,
-        request: Union[firestore_admin.ExportDocumentsRequest, dict] = None,
+        request: Optional[Union[firestore_admin.ExportDocumentsRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Exports a copy of all or a subset of documents from
@@ -1475,11 +1488,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def import_documents(
         self,
-        request: Union[firestore_admin.ImportDocumentsRequest, dict] = None,
+        request: Optional[Union[firestore_admin.ImportDocumentsRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Imports documents into Google Cloud Firestore.
@@ -1605,11 +1618,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def get_database(
         self,
-        request: Union[firestore_admin.GetDatabaseRequest, dict] = None,
+        request: Optional[Union[firestore_admin.GetDatabaseRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> database.Database:
         r"""Gets information about a database.
@@ -1709,11 +1722,11 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def list_databases(
         self,
-        request: Union[firestore_admin.ListDatabasesRequest, dict] = None,
+        request: Optional[Union[firestore_admin.ListDatabasesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firestore_admin.ListDatabasesResponse:
         r"""List all the databases in the project.
@@ -1809,12 +1822,12 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def update_database(
         self,
-        request: Union[firestore_admin.UpdateDatabaseRequest, dict] = None,
+        request: Optional[Union[firestore_admin.UpdateDatabaseRequest, dict]] = None,
         *,
-        database: gfa_database.Database = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        database: Optional[gfa_database.Database] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Updates a database.
@@ -1947,10 +1960,10 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -2001,10 +2014,10 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -2055,10 +2068,10 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -2110,10 +2123,10 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
 
     def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -2163,14 +2176,9 @@ class FirestoreAdminClient(metaclass=FirestoreAdminClientMeta):
         )
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-firestore-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("FirestoreAdminClient",)
