@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.firestore_admin_v1.types import database as gfa_database
@@ -54,19 +56,24 @@ class ListDatabasesRequest(proto.Message):
             ``projects/{project_id}``
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDatabasesResponse(proto.Message):
     r"""The list of databases for a project.
 
     Attributes:
-        databases (Sequence[google.cloud.firestore_admin_v1.types.Database]):
+        databases (MutableSequence[google.cloud.firestore_admin_v1.types.Database]):
             The databases in the project.
     """
 
-    databases = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gfa_database.Database,
+    databases: MutableSequence[gfa_database.Database] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gfa_database.Database,
     )
 
 
@@ -80,7 +87,10 @@ class GetDatabaseRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateDatabaseRequest(proto.Message):
@@ -94,15 +104,20 @@ class UpdateDatabaseRequest(proto.Message):
             The list of fields to be updated.
     """
 
-    database = proto.Field(proto.MESSAGE, number=1, message=gfa_database.Database,)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    database: gfa_database.Database = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gfa_database.Database,
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
 class UpdateDatabaseMetadata(proto.Message):
-    r"""Metadata related to the update database operation.
-    """
+    r"""Metadata related to the update database operation."""
 
 
 class CreateIndexRequest(proto.Message):
@@ -117,8 +132,15 @@ class CreateIndexRequest(proto.Message):
             Required. The composite index to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    index = proto.Field(proto.MESSAGE, number=2, message=gfa_index.Index,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    index: gfa_index.Index = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gfa_index.Index,
+    )
 
 
 class ListIndexesRequest(proto.Message):
@@ -139,10 +161,22 @@ class ListIndexesRequest(proto.Message):
             that may be used to get the next page of results.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListIndexesResponse(proto.Message):
@@ -150,7 +184,7 @@ class ListIndexesResponse(proto.Message):
     [FirestoreAdmin.ListIndexes][google.firestore.admin.v1.FirestoreAdmin.ListIndexes].
 
     Attributes:
-        indexes (Sequence[google.cloud.firestore_admin_v1.types.Index]):
+        indexes (MutableSequence[google.cloud.firestore_admin_v1.types.Index]):
             The requested indexes.
         next_page_token (str):
             A page token that may be used to request
@@ -162,8 +196,15 @@ class ListIndexesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    indexes = proto.RepeatedField(proto.MESSAGE, number=1, message=gfa_index.Index,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    indexes: MutableSequence[gfa_index.Index] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gfa_index.Index,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetIndexRequest(proto.Message):
@@ -176,7 +217,10 @@ class GetIndexRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteIndexRequest(proto.Message):
@@ -189,7 +233,10 @@ class DeleteIndexRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateFieldRequest(proto.Message):
@@ -205,9 +252,15 @@ class UpdateFieldRequest(proto.Message):
             in the field.
     """
 
-    field = proto.Field(proto.MESSAGE, number=1, message=gfa_field.Field,)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    field: gfa_field.Field = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gfa_field.Field,
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -221,7 +274,10 @@ class GetFieldRequest(proto.Message):
             ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/fields/{field_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListFieldsRequest(proto.Message):
@@ -248,10 +304,22 @@ class ListFieldsRequest(proto.Message):
             that may be used to get the next page of results.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListFieldsResponse(proto.Message):
@@ -259,7 +327,7 @@ class ListFieldsResponse(proto.Message):
     [FirestoreAdmin.ListFields][google.firestore.admin.v1.FirestoreAdmin.ListFields].
 
     Attributes:
-        fields (Sequence[google.cloud.firestore_admin_v1.types.Field]):
+        fields (MutableSequence[google.cloud.firestore_admin_v1.types.Field]):
             The requested fields.
         next_page_token (str):
             A page token that may be used to request
@@ -271,8 +339,15 @@ class ListFieldsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    fields = proto.RepeatedField(proto.MESSAGE, number=1, message=gfa_field.Field,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    fields: MutableSequence[gfa_field.Field] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gfa_field.Field,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ExportDocumentsRequest(proto.Message):
@@ -283,7 +358,7 @@ class ExportDocumentsRequest(proto.Message):
         name (str):
             Required. Database to export. Should be of the form:
             ``projects/{project_id}/databases/{database_id}``.
-        collection_ids (Sequence[str]):
+        collection_ids (MutableSequence[str]):
             Which collection ids to export. Unspecified
             means all collections.
         output_uri_prefix (str):
@@ -298,9 +373,18 @@ class ExportDocumentsRequest(proto.Message):
             generated based on the start time.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    collection_ids = proto.RepeatedField(proto.STRING, number=2,)
-    output_uri_prefix = proto.Field(proto.STRING, number=3,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    collection_ids: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    output_uri_prefix: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ImportDocumentsRequest(proto.Message):
@@ -311,7 +395,7 @@ class ImportDocumentsRequest(proto.Message):
         name (str):
             Required. Database to import into. Should be of the form:
             ``projects/{project_id}/databases/{database_id}``.
-        collection_ids (Sequence[str]):
+        collection_ids (MutableSequence[str]):
             Which collection ids to import. Unspecified
             means all collections included in the import.
         input_uri_prefix (str):
@@ -321,9 +405,18 @@ class ImportDocumentsRequest(proto.Message):
             [google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix][google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix].
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    collection_ids = proto.RepeatedField(proto.STRING, number=2,)
-    input_uri_prefix = proto.Field(proto.STRING, number=3,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    collection_ids: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    input_uri_prefix: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
