@@ -19,6 +19,8 @@ import re
 from typing import (
     Dict,
     Mapping,
+    MutableMapping,
+    MutableSequence,
     Optional,
     Iterable,
     Iterator,
@@ -26,8 +28,10 @@ from typing import (
     Tuple,
     Type,
     Union,
+    cast,
 )
-import pkg_resources
+
+from google.cloud.firestore_v1 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -75,7 +79,7 @@ class FirestoreClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[FirestoreTransport]:
         """Returns an appropriate transport class.
 
@@ -336,8 +340,8 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, FirestoreTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, FirestoreTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the firestore client.
@@ -351,7 +355,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             transport (Union[str, FirestoreTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -381,6 +385,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -433,10 +438,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def get_document(
         self,
-        request: Union[firestore.GetDocumentRequest, dict] = None,
+        request: Optional[Union[firestore.GetDocumentRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document.Document:
         r"""Gets a single document.
@@ -515,10 +520,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def list_documents(
         self,
-        request: Union[firestore.ListDocumentsRequest, dict] = None,
+        request: Optional[Union[firestore.ListDocumentsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDocumentsPager:
         r"""Lists documents.
@@ -616,12 +621,12 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def update_document(
         self,
-        request: Union[firestore.UpdateDocumentRequest, dict] = None,
+        request: Optional[Union[firestore.UpdateDocumentRequest, dict]] = None,
         *,
-        document: gf_document.Document = None,
-        update_mask: common.DocumentMask = None,
+        document: Optional[gf_document.Document] = None,
+        update_mask: Optional[common.DocumentMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gf_document.Document:
         r"""Updates or inserts a document.
@@ -737,11 +742,11 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def delete_document(
         self,
-        request: Union[firestore.DeleteDocumentRequest, dict] = None,
+        request: Optional[Union[firestore.DeleteDocumentRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a document.
@@ -828,10 +833,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def batch_get_documents(
         self,
-        request: Union[firestore.BatchGetDocumentsRequest, dict] = None,
+        request: Optional[Union[firestore.BatchGetDocumentsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Iterable[firestore.BatchGetDocumentsResponse]:
         r"""Gets multiple documents.
@@ -913,11 +918,11 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def begin_transaction(
         self,
-        request: Union[firestore.BeginTransactionRequest, dict] = None,
+        request: Optional[Union[firestore.BeginTransactionRequest, dict]] = None,
         *,
-        database: str = None,
+        database: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firestore.BeginTransactionResponse:
         r"""Starts a new transaction.
@@ -1015,12 +1020,12 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def commit(
         self,
-        request: Union[firestore.CommitRequest, dict] = None,
+        request: Optional[Union[firestore.CommitRequest, dict]] = None,
         *,
-        database: str = None,
-        writes: Sequence[gf_write.Write] = None,
+        database: Optional[str] = None,
+        writes: Optional[MutableSequence[gf_write.Write]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firestore.CommitResponse:
         r"""Commits a transaction, while optionally updating
@@ -1063,7 +1068,7 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
                 This corresponds to the ``database`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            writes (Sequence[google.cloud.firestore_v1.types.Write]):
+            writes (MutableSequence[google.cloud.firestore_v1.types.Write]):
                 The writes to apply.
                 Always executed atomically and in order.
 
@@ -1128,12 +1133,12 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def rollback(
         self,
-        request: Union[firestore.RollbackRequest, dict] = None,
+        request: Optional[Union[firestore.RollbackRequest, dict]] = None,
         *,
-        database: str = None,
-        transaction: bytes = None,
+        database: Optional[str] = None,
+        transaction: Optional[bytes] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Rolls back a transaction.
@@ -1229,10 +1234,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def run_query(
         self,
-        request: Union[firestore.RunQueryRequest, dict] = None,
+        request: Optional[Union[firestore.RunQueryRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Iterable[firestore.RunQueryResponse]:
         r"""Runs a query.
@@ -1312,10 +1317,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def run_aggregation_query(
         self,
-        request: Union[firestore.RunAggregationQueryRequest, dict] = None,
+        request: Optional[Union[firestore.RunAggregationQueryRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Iterable[firestore.RunAggregationQueryResponse]:
         r"""Runs an aggregation query.
@@ -1409,10 +1414,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def partition_query(
         self,
-        request: Union[firestore.PartitionQueryRequest, dict] = None,
+        request: Optional[Union[firestore.PartitionQueryRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.PartitionQueryPager:
         r"""Partitions a query by returning partition cursors
@@ -1507,10 +1512,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def write(
         self,
-        requests: Iterator[firestore.WriteRequest] = None,
+        requests: Optional[Iterator[firestore.WriteRequest]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Iterable[firestore.WriteResponse]:
         r"""Streams batches of document updates and deletes, in
@@ -1601,10 +1606,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def listen(
         self,
-        requests: Iterator[firestore.ListenRequest] = None,
+        requests: Optional[Iterator[firestore.ListenRequest]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Iterable[firestore.ListenResponse]:
         r"""Listens to changes.
@@ -1688,11 +1693,11 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def list_collection_ids(
         self,
-        request: Union[firestore.ListCollectionIdsRequest, dict] = None,
+        request: Optional[Union[firestore.ListCollectionIdsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCollectionIdsPager:
         r"""Lists all the collection IDs underneath a document.
@@ -1805,10 +1810,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def batch_write(
         self,
-        request: Union[firestore.BatchWriteRequest, dict] = None,
+        request: Optional[Union[firestore.BatchWriteRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firestore.BatchWriteResponse:
         r"""Applies a batch of write operations.
@@ -1896,10 +1901,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def create_document(
         self,
-        request: Union[firestore.CreateDocumentRequest, dict] = None,
+        request: Optional[Union[firestore.CreateDocumentRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document.Document:
         r"""Creates a new document.
@@ -1996,10 +2001,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -2050,10 +2055,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -2104,10 +2109,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -2159,10 +2164,10 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
 
     def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -2212,14 +2217,9 @@ class FirestoreClient(metaclass=FirestoreClientMeta):
         )
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-firestore",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("FirestoreClient",)
