@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.firestore_v1.types import document
@@ -23,6 +25,7 @@ __protobuf__ = proto.module(
     package="google.firestore.v1",
     manifest={
         "StructuredQuery",
+        "StructuredAggregationQuery",
         "Cursor",
     },
 )
@@ -34,19 +37,23 @@ class StructuredQuery(proto.Message):
     Attributes:
         select (google.cloud.firestore_v1.types.StructuredQuery.Projection):
             The projection to return.
-        from_ (Sequence[google.cloud.firestore_v1.types.StructuredQuery.CollectionSelector]):
+        from_ (MutableSequence[google.cloud.firestore_v1.types.StructuredQuery.CollectionSelector]):
             The collections to query.
         where (google.cloud.firestore_v1.types.StructuredQuery.Filter):
             The filter to apply.
-        order_by (Sequence[google.cloud.firestore_v1.types.StructuredQuery.Order]):
+        order_by (MutableSequence[google.cloud.firestore_v1.types.StructuredQuery.Order]):
             The order to apply to the query results.
 
+            Firestore allows callers to provide a full ordering, a
+            partial ordering, or no ordering at all. In all cases,
             Firestore guarantees a stable ordering through the following
             rules:
 
-            -  Any field required to appear in ``order_by``, that is not
-               already specified in ``order_by``, is appended to the
-               order in field name order by default.
+            -  The ``order_by`` is required to reference all fields used
+               with an inequality filter.
+            -  All fields that are required to be in the ``order_by``
+               but are not already present are appended in
+               lexicographical ordering of the field name.
             -  If an order on ``__name__`` is not specified, it is
                appended by default.
 
@@ -54,24 +61,81 @@ class StructuredQuery(proto.Message):
             order specified, or 'ASCENDING' if no order was specified.
             For example:
 
-            -  ``SELECT * FROM Foo ORDER BY A`` becomes
-               ``SELECT * FROM Foo ORDER BY A, __name__``
-            -  ``SELECT * FROM Foo ORDER BY A DESC`` becomes
-               ``SELECT * FROM Foo ORDER BY A DESC, __name__ DESC``
-            -  ``SELECT * FROM Foo WHERE A > 1`` becomes
-               ``SELECT * FROM Foo WHERE A > 1 ORDER BY A, __name__``
+            -  ``ORDER BY a`` becomes ``ORDER BY a ASC, __name__ ASC``
+            -  ``ORDER BY a DESC`` becomes
+               ``ORDER BY a DESC, __name__ DESC``
+            -  ``WHERE a > 1`` becomes
+               ``WHERE a > 1 ORDER BY a ASC, __name__ ASC``
+            -  ``WHERE __name__ > ... AND a > 1`` becomes
+               ``WHERE __name__ > ... AND a > 1 ORDER BY a ASC, __name__ ASC``
         start_at (google.cloud.firestore_v1.types.Cursor):
-            A starting point for the query results.
+            A potential prefix of a position in the result set to start
+            the query at.
+
+            The ordering of the result set is based on the ``ORDER BY``
+            clause of the original query.
+
+            ::
+
+               SELECT * FROM k WHERE a = 1 AND b > 2 ORDER BY b ASC, __name__ ASC;
+
+            This query's results are ordered by
+            ``(b ASC, __name__ ASC)``.
+
+            Cursors can reference either the full ordering or a prefix
+            of the location, though it cannot reference more fields than
+            what are in the provided ``ORDER BY``.
+
+            Continuing off the example above, attaching the following
+            start cursors will have varying impact:
+
+            -  ``START BEFORE (2, /k/123)``: start the query right
+               before ``a = 1 AND b > 2 AND __name__ > /k/123``.
+            -  ``START AFTER (10)``: start the query right after
+               ``a = 1 AND b > 10``.
+
+            Unlike ``OFFSET`` which requires scanning over the first N
+            results to skip, a start cursor allows the query to begin at
+            a logical position. This position is not required to match
+            an actual result, it will scan forward from this position to
+            find the next document.
+
+            Requires:
+
+            -  The number of values cannot be greater than the number of
+               fields specified in the ``ORDER BY`` clause.
         end_at (google.cloud.firestore_v1.types.Cursor):
-            A end point for the query results.
+            A potential prefix of a position in the result set to end
+            the query at.
+
+            This is similar to ``START_AT`` but with it controlling the
+            end position rather than the start position.
+
+            Requires:
+
+            -  The number of values cannot be greater than the number of
+               fields specified in the ``ORDER BY`` clause.
         offset (int):
-            The number of results to skip.
-            Applies before limit, but after all other
-            constraints. Must be >= 0 if specified.
+            The number of documents to skip before returning the first
+            result.
+
+            This applies after the constraints specified by the
+            ``WHERE``, ``START AT``, & ``END AT`` but before the
+            ``LIMIT`` clause.
+
+            Requires:
+
+            -  The value must be greater than or equal to zero if
+               specified.
         limit (google.protobuf.wrappers_pb2.Int32Value):
             The maximum number of results to return.
+
             Applies after all other constraints.
-            Must be >= 0 if specified.
+
+            Requires:
+
+            -  The value must be greater than or equal to zero if
+               specified.
     """
 
     class Direction(proto.Enum):
@@ -94,11 +158,11 @@ class StructuredQuery(proto.Message):
                 collections.
         """
 
-        collection_id = proto.Field(
+        collection_id: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        all_descendants = proto.Field(
+        all_descendants: bool = proto.Field(
             proto.BOOL,
             number=3,
         )
@@ -128,19 +192,19 @@ class StructuredQuery(proto.Message):
                 This field is a member of `oneof`_ ``filter_type``.
         """
 
-        composite_filter = proto.Field(
+        composite_filter: "StructuredQuery.CompositeFilter" = proto.Field(
             proto.MESSAGE,
             number=1,
             oneof="filter_type",
             message="StructuredQuery.CompositeFilter",
         )
-        field_filter = proto.Field(
+        field_filter: "StructuredQuery.FieldFilter" = proto.Field(
             proto.MESSAGE,
             number=2,
             oneof="filter_type",
             message="StructuredQuery.FieldFilter",
         )
-        unary_filter = proto.Field(
+        unary_filter: "StructuredQuery.UnaryFilter" = proto.Field(
             proto.MESSAGE,
             number=3,
             oneof="filter_type",
@@ -154,7 +218,7 @@ class StructuredQuery(proto.Message):
         Attributes:
             op (google.cloud.firestore_v1.types.StructuredQuery.CompositeFilter.Operator):
                 The operator for combining multiple filters.
-            filters (Sequence[google.cloud.firestore_v1.types.StructuredQuery.Filter]):
+            filters (MutableSequence[google.cloud.firestore_v1.types.StructuredQuery.Filter]):
                 The list of filters to combine.
 
                 Requires:
@@ -167,12 +231,12 @@ class StructuredQuery(proto.Message):
             OPERATOR_UNSPECIFIED = 0
             AND = 1
 
-        op = proto.Field(
+        op: "StructuredQuery.CompositeFilter.Operator" = proto.Field(
             proto.ENUM,
             number=1,
             enum="StructuredQuery.CompositeFilter.Operator",
         )
-        filters = proto.RepeatedField(
+        filters: MutableSequence["StructuredQuery.Filter"] = proto.RepeatedField(
             proto.MESSAGE,
             number=2,
             message="StructuredQuery.Filter",
@@ -204,17 +268,17 @@ class StructuredQuery(proto.Message):
             ARRAY_CONTAINS_ANY = 9
             NOT_IN = 10
 
-        field = proto.Field(
+        field: "StructuredQuery.FieldReference" = proto.Field(
             proto.MESSAGE,
             number=1,
             message="StructuredQuery.FieldReference",
         )
-        op = proto.Field(
+        op: "StructuredQuery.FieldFilter.Operator" = proto.Field(
             proto.ENUM,
             number=2,
             enum="StructuredQuery.FieldFilter.Operator",
         )
-        value = proto.Field(
+        value: document.Value = proto.Field(
             proto.MESSAGE,
             number=3,
             message=document.Value,
@@ -242,12 +306,12 @@ class StructuredQuery(proto.Message):
             IS_NOT_NAN = 4
             IS_NOT_NULL = 5
 
-        op = proto.Field(
+        op: "StructuredQuery.UnaryFilter.Operator" = proto.Field(
             proto.ENUM,
             number=1,
             enum="StructuredQuery.UnaryFilter.Operator",
         )
-        field = proto.Field(
+        field: "StructuredQuery.FieldReference" = proto.Field(
             proto.MESSAGE,
             number=2,
             oneof="operand_type",
@@ -264,26 +328,31 @@ class StructuredQuery(proto.Message):
                 The direction to order by. Defaults to ``ASCENDING``.
         """
 
-        field = proto.Field(
+        field: "StructuredQuery.FieldReference" = proto.Field(
             proto.MESSAGE,
             number=1,
             message="StructuredQuery.FieldReference",
         )
-        direction = proto.Field(
+        direction: "StructuredQuery.Direction" = proto.Field(
             proto.ENUM,
             number=2,
             enum="StructuredQuery.Direction",
         )
 
     class FieldReference(proto.Message):
-        r"""A reference to a field, such as ``max(messages.time) as max_time``.
+        r"""A reference to a field in a document, ex: ``stats.operations``.
 
         Attributes:
             field_path (str):
+                The relative path of the document being referenced.
 
+                Requires:
+
+                -  Conform to [document field
+                   name][google.firestore.v1.Document.fields] limitations.
         """
 
-        field_path = proto.Field(
+        field_path: str = proto.Field(
             proto.STRING,
             number=2,
         )
@@ -292,65 +361,193 @@ class StructuredQuery(proto.Message):
         r"""The projection of document's fields to return.
 
         Attributes:
-            fields (Sequence[google.cloud.firestore_v1.types.StructuredQuery.FieldReference]):
+            fields (MutableSequence[google.cloud.firestore_v1.types.StructuredQuery.FieldReference]):
                 The fields to return.
 
                 If empty, all fields are returned. To only return the name
                 of the document, use ``['__name__']``.
         """
 
-        fields = proto.RepeatedField(
+        fields: MutableSequence["StructuredQuery.FieldReference"] = proto.RepeatedField(
             proto.MESSAGE,
             number=2,
             message="StructuredQuery.FieldReference",
         )
 
-    select = proto.Field(
+    select: Projection = proto.Field(
         proto.MESSAGE,
         number=1,
         message=Projection,
     )
-    from_ = proto.RepeatedField(
+    from_: MutableSequence[CollectionSelector] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message=CollectionSelector,
     )
-    where = proto.Field(
+    where: Filter = proto.Field(
         proto.MESSAGE,
         number=3,
         message=Filter,
     )
-    order_by = proto.RepeatedField(
+    order_by: MutableSequence[Order] = proto.RepeatedField(
         proto.MESSAGE,
         number=4,
         message=Order,
     )
-    start_at = proto.Field(
+    start_at: "Cursor" = proto.Field(
         proto.MESSAGE,
         number=7,
         message="Cursor",
     )
-    end_at = proto.Field(
+    end_at: "Cursor" = proto.Field(
         proto.MESSAGE,
         number=8,
         message="Cursor",
     )
-    offset = proto.Field(
+    offset: int = proto.Field(
         proto.INT32,
         number=6,
     )
-    limit = proto.Field(
+    limit: wrappers_pb2.Int32Value = proto.Field(
         proto.MESSAGE,
         number=5,
         message=wrappers_pb2.Int32Value,
     )
 
 
+class StructuredAggregationQuery(proto.Message):
+    r"""Firestore query for running an aggregation over a
+    [StructuredQuery][google.firestore.v1.StructuredQuery].
+
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        structured_query (google.cloud.firestore_v1.types.StructuredQuery):
+            Nested structured query.
+
+            This field is a member of `oneof`_ ``query_type``.
+        aggregations (MutableSequence[google.cloud.firestore_v1.types.StructuredAggregationQuery.Aggregation]):
+            Optional. Series of aggregations to apply over the results
+            of the ``structured_query``.
+
+            Requires:
+
+            -  A minimum of one and maximum of five aggregations per
+               query.
+    """
+
+    class Aggregation(proto.Message):
+        r"""Defines a aggregation that produces a single result.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+        Attributes:
+            count (google.cloud.firestore_v1.types.StructuredAggregationQuery.Aggregation.Count):
+                Count aggregator.
+
+                This field is a member of `oneof`_ ``operator``.
+            alias (str):
+                Optional. Optional name of the field to store the result of
+                the aggregation into.
+
+                If not provided, Firestore will pick a default name
+                following the format ``field_<incremental_id++>``. For
+                example:
+
+                ::
+
+                   AGGREGATE
+                     COUNT_UP_TO(1) AS count_up_to_1,
+                     COUNT_UP_TO(2),
+                     COUNT_UP_TO(3) AS count_up_to_3,
+                     COUNT_UP_TO(4)
+                   OVER (
+                     ...
+                   );
+
+                becomes:
+
+                ::
+
+                   AGGREGATE
+                     COUNT_UP_TO(1) AS count_up_to_1,
+                     COUNT_UP_TO(2) AS field_1,
+                     COUNT_UP_TO(3) AS count_up_to_3,
+                     COUNT_UP_TO(4) AS field_2
+                   OVER (
+                     ...
+                   );
+
+                Requires:
+
+                -  Must be unique across all aggregation aliases.
+                -  Conform to [document field
+                   name][google.firestore.v1.Document.fields] limitations.
+        """
+
+        class Count(proto.Message):
+            r"""Count of documents that match the query.
+
+            The ``COUNT(*)`` aggregation function operates on the entire
+            document so it does not require a field reference.
+
+            Attributes:
+                up_to (google.protobuf.wrappers_pb2.Int64Value):
+                    Optional. Optional constraint on the maximum number of
+                    documents to count.
+
+                    This provides a way to set an upper bound on the number of
+                    documents to scan, limiting latency and cost.
+
+                    Unspecified is interpreted as no bound.
+
+                    High-Level Example:
+
+                    ::
+
+                       AGGREGATE COUNT_UP_TO(1000) OVER ( SELECT * FROM k );
+
+                    Requires:
+
+                    -  Must be greater than zero when present.
+            """
+
+            up_to: wrappers_pb2.Int64Value = proto.Field(
+                proto.MESSAGE,
+                number=1,
+                message=wrappers_pb2.Int64Value,
+            )
+
+        count: "StructuredAggregationQuery.Aggregation.Count" = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            oneof="operator",
+            message="StructuredAggregationQuery.Aggregation.Count",
+        )
+        alias: str = proto.Field(
+            proto.STRING,
+            number=7,
+        )
+
+    structured_query: "StructuredQuery" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        oneof="query_type",
+        message="StructuredQuery",
+    )
+    aggregations: MutableSequence[Aggregation] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message=Aggregation,
+    )
+
+
 class Cursor(proto.Message):
     r"""A position in a query result set.
 
     Attributes:
-        values (Sequence[google.cloud.firestore_v1.types.Value]):
+        values (MutableSequence[google.cloud.firestore_v1.types.Value]):
             The values that represent a position, in the
             order they appear in the order by clause of a
             query.
@@ -362,12 +559,12 @@ class Cursor(proto.Message):
             defined by the query.
     """
 
-    values = proto.RepeatedField(
+    values: MutableSequence[document.Value] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=document.Value,
     )
-    before = proto.Field(
+    before: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
